pub fn float_vec_linspace(start: f64, end: f64, num: usize) -> Vec<f64>Expand description
Create a vector with evenly spaced floating point values.
This function generates a vector with num values starting from start, ending at end, and evenly spaced.
Parameters
start: The starting value of the range.end: The end value of the range (inclusive).num: The number of points to generate in the range.
Returns
A vector containing the generated floating point values.